<?php

namespace Ebuy\Address\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Ebuy\Address\Repositories\Eloquent\Filters\AddressPublicFilter;
use Ebuy\Address\Repositories\Eloquent\Presenters\AddressListPresenter;
use Ebuy\Address\Interfaces\AddressRepositoryInterface;

class AddressPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(AddressRepositoryInterface $address)
    {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.address.modules'), 'address', guard_url('address'));
        $this->repository = $address;

    }

    /**
     * Show address's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(AddressPublicFilter::class)
            ->setPresenter(AddressListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('address::address.names'))
            ->view('address::public.address.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show address.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('address::address.name'))
            ->view('address::public.address.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
