<?php

namespace Ebuy\Address\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Ebuy\Address\Models\Address;

class AddressPolicy
{

    /**
     * Determine if the given user can view the address.
     *
     * @param UserPolicyInterface $authUser
     * @param Address $address
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Address $address)
    {
        if ($authUser->canDo('address.address.view') && $authUser->isAdmin()) {
            return true;
        }

        return $address->user_id == user_id() && $address->user_type == user_type();
    }

    /**
     * Determine if the given user can create a address.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('address.address.create');
    }

    /**
     * Determine if the given user can update the given address.
     *
     * @param UserPolicyInterface $authUser
     * @param Address $address
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Address $address)
    {
        if ($authUser->canDo('address.address.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $address->user_id == user_id() && $address->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given address.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Address $address)
    {
        return $address->user_id == user_id() && $address->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given address.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Address $address)
    {
        if ($authUser->canDo('address.address.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given address.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Address $address)
    {
        if ($authUser->canDo('address.address.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
